@@ -18,36 +18,69 @@
 
 from __future__ import absolute_import
 from ofxparse import OfxParser
+from ledgerautosync.converter import CsvConverter
 from ofxparse.ofxparse import InvestmentTransaction
 import logging
-
+import csv
 
 class Synchronizer(object):
     def __init__(self, lgr):
         self.lgr = lgr
 
+class OfxSynchronizer(Synchronizer):
+    def __init__(self, lgr):
+        super(OfxSynchronizer, self).__init__(lgr)
+
     def parse_file(self, path, accountname=None):
         ofx = OfxParser.parse(file(path))
         return (ofx, self.filter(ofx))
 
     def is_txn_synced(self, acctid, txn):
-        ofxid = "%s.%s" % (acctid, txn.id)
-        return self.lgr.check_transaction_by_ofxid(ofxid)
+        if self.lgr is None:
+            # User called with --no-ledger
+            # All transactions are considered "synced" in this case.
+            return False
+        else:
+            ofxid = "%s.%s" % (acctid, txn.id)
+            return self.lgr.check_transaction_by_id("ofxid", ofxid)
+
+    # Filter out comment transactions. These have an amount of 0 and the same
+    # datetime as the previous transactions.
+    def filter_comment_txns(self, txns):
+        last_txn = None
+        retval = []
+        for txn in txns:
+            if (last_txn is not None) and \
+               hasattr(txn, 'amount') and \
+               (txn.amount == 0) and \
+               hasattr(last_txn, 'date') and \
+               hasattr(txn, 'date') and \
+               (last_txn.date == txn.date):
+                # This is a comment transaction
+                pass
+            else:
+                last_txn = txn
+                retval.append(txn)
+        return retval
 
     def filter(self, ofx):
+        def extract_sort_key(txn):
+            if hasattr(txn, 'tradeDate'):
+                return txn.tradeDate
+            elif hasattr(txn, 'date'):
+                return txn.date
+            elif hasattr(txn, 'settleDate'):
+                return txn.settleDate
+            return None
         txns = ofx.account.statement.transactions
         if len(txns) == 0:
             sorted_txns = txns
-        elif all(isinstance(txn, InvestmentTransaction) for txn in txns):
-            if all(txn.settleDate is not None for txn in txns):
-                sorted_txns = sorted(txns, key=lambda t: t.settleDate)
-            else:
-                sorted_txns = sorted(txns, key=lambda t: t.tradeDate)
         else:
-            sorted_txns = sorted(txns, key=lambda t: t.date)
+            sorted_txns = sorted(txns, key=extract_sort_key)
         acctid = ofx.account.account_id
-        return [txn for txn in sorted_txns
-                if not(self.is_txn_synced(acctid, txn))]
+        retval = [txn for txn in sorted_txns
+                  if not(self.is_txn_synced(acctid, txn))]
+        return self.filter_comment_txns(retval)
 
     def get_new_txns(self, acct, max_days=999999, resync=False):
         if resync or (max_days < 7):
@@ -104,3 +137,24 @@ class Synchronizer(object):
                         days = max_days
                     logging.debug("Increasing days ago to %d." % (days))
                     last_txns_len = len(txns)
+
+
+class CsvSynchronizer(Synchronizer):
+    def __init__(self, lgr):
+        super(CsvSynchronizer, self).__init__(lgr)
+
+    def parse_file(self, path, accountname=None, unknownaccount=None):
+        with open(path, 'rb') as f:
+            dialect = csv.Sniffer().sniff(f.read(1024))
+            f.seek(0)
+            dialect.skipinitialspace = True
+            reader = csv.DictReader(f, dialect=dialect)
+            converter = CsvConverter.make_converter(
+                reader,
+                name=accountname,
+                ledger=self.lgr,
+                unknownaccount=unknownaccount)
+            return [converter.convert(row)
+                    for row in reader
+                    if not(self.lgr.check_transaction_by_id(
+                            "csvid", converter.get_csv_id(row)))]
