@@ -1,5 +1,5 @@
-# Copyright (c) 2013, 2014 Erik Hetzner
-# 
+# Copyright (c) 2013-2015 Erik Hetzner
+#
 # This file is part of ledger-autosync
 #
 # ledger-autosync is free software: you can redistribute it and/or
@@ -15,3 +15,15 @@
 # You should have received a copy of the GNU General Public License
 # along with ledger-autosync. If not, see
 # <http://www.gnu.org/licenses/>.
+
+from unittest import TestCase
+import re
+
+
+class LedgerTestCase(TestCase):
+    def assertEqualLedgerPosting(self, a, b, msg=None):
+        """Checks that two strings are the same posting. Collapses all space
+        sequences > len(2)."""
+        a1 = re.sub('  +', '  ', a)
+        b1 = re.sub('  +', '  ', b)
+        return self.assertEqual(a1, b1, msg=msg)
